PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/tests.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

tests.h
Go to the documentation of this file.
1 #ifndef TESTS_H
2 #define TESTS_H
3 #include "sbt.h"
4
5 double Ylmr(int l, int m, double theta, double phi);
6 double Ylmi(int l, int m, double theta, double phi);
7
8 int fft_check(char* wavecar, double* kpt_weights, int* fftg);
9
10 #endif
Ylmr
double Ylmr(int l, int m, double theta, double phi)
sbt.h
Ylmi
double Ylmi(int l, int m, double theta, double phi)
fft_check
int fft_check(char *wavecar, double *kpt_weights, int *fftg)